"""A python package to help facilitate the collection and analysis of education-related datasets. """

__version__ = '0.141'


from pypeds.ipeds import *
from pypeds.datasets import *
from pypeds.views import *



